==> bacula-doc_1.38.11.1.orig.tar.gz: bacula-docs-1.38.11-1/home-page/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - The Network Backup Solution
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> is a set of computer programs that permit you
     (or the system administrator) to manage backup, recovery,
     and verification of computer data across a network of
     computers of different kinds.<br>

     <br>
     In technical terms, it is a <b>network based backup program</b>.<br>

     <br>
     Bacula is relatively easy to use and efficient, while
     offering many advanced storage management features that make
     it easy to find and recover lost or damaged files.<br> 

     <br>
     Most of the <b>Bacula</b> source code has been released
     under a slightly modified version of the <b>GPL</b> version
     2 license.  If you wish additional details, please follow
     the License link to your left.<br>

     <br>The Documentation link takes you to a page where you
     can access all the available Bacula documentation (HTML,
     PDF, and TGZ) both for the officially released version 
     and for the current code under development in the Source
     Forge CVS. The development version of the manual typically has
     more documentation, but may also document new features that are
     not in the released version.  The Developer's Guide
     presents important information for users who want to
     contribute to the Bacula project.<br>  
        
     <br> Bacula is Hosted on
     SourceForge at <a href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> where you can
     download the software.<br> <br> You may also use
     the links on the left side of this page for more
     information.  In particular, Current Files link takes
     you to the currently available downloads, and the All
     Downloads link takes you to a list of all files ever
     released to SourceForge.
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>

==> bacula-doc_2.4.4.orig.tar.gz: bacula-docs-2.4.4/home-page/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - The Network Backup Solution
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> is a set of computer programs that permit you
     (or the system administrator) to manage backup, recovery,
     and verification of computer data across a network of
     computers of different kinds.<br>

     <br>     
     <b>Serious Bug</b> - All users should read <a href="?page=news">
     this news item</a> regarding a serious bug.  A fix has been found
     and patches are being tested. Please subscribe to the 
     <a href="?page=maillists">announce mailing list</a> to be kept informed.<br>

     <br>
     In technical terms, it is a <b>network based backup program</b>.<br>

     <br>
     Bacula is relatively easy to use and efficient, while
     offering many advanced storage management features that make
     it easy to find and recover lost or damaged files.<br> 

     <br>
     Most of the <b>Bacula</b> source code is released under the
     <b>GPL</b> version 2 license.  If you wish additional
     details, please follow the License link to your left.<br>

     <br>The Documentation link takes you to a page where you
     can access all the available Bacula documentation (HTML,
     PDF, and TGZ) both for the officially released version 
     and for the current code under development in the Source
     Forge SVN. The development version of the manual typically has
     more documentation, but may also document new features that are
     not in the released version.  The Developer's Guide
     presents important information for users who want to
     contribute to the Bacula project.<br>  
        
     <br> Bacula is Hosted on
     SourceForge at <a href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> where you can
     download the software.<br> <br> You may also use
     the links on the left side of this page for more
     information.  In particular, Current Files link takes
     you to the currently available downloads, and the All
     Downloads link takes you to a list of all files ever
     released to SourceForge.
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>
